# Models

All API responses are parsed into typed Pydantic models. Fields are accessible as regular Python attributes.

::: xanax.models.Wallpaper

::: xanax.models.SearchResult

::: xanax.models.PaginationMeta

::: xanax.models.Tag

::: xanax.models.Uploader

::: xanax.models.Avatar

::: xanax.models.Thumbnails

::: xanax.models.QueryInfo

::: xanax.models.UserSettings

::: xanax.models.Collection

::: xanax.models.CollectionListing

::: xanax.pagination.PaginationHelper
